@@ -6,11 +6,11 @@ package config
 import (
 	"fmt"
 
-	"github.com/ghodss/yaml"
 	semver "github.com/hashicorp/go-version"
 	ctlres "github.com/vmware-tanzu/carvel-kapp/pkg/kapp/resources"
 	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/version"
 	"github.com/vmware-tanzu/carvel-kapp/pkg/kapp/yttresmod"
+	"sigs.k8s.io/yaml"
 )
 
 const (
@@ -33,6 +33,7 @@ type Config struct {
 
 	AdditionalLabels                          map[string]string
 	DiffAgainstLastAppliedFieldExclusionRules []DiffAgainstLastAppliedFieldExclusionRule
+	DiffAgainstExistingFieldExclusionRules    []DiffAgainstExistingFieldExclusionRule
 
 	// TODO additional?
 	// TODO validations
@@ -96,6 +97,11 @@ type DiffAgainstLastAppliedFieldExclusionRule struct {
 	Path             ctlres.Path
 }
 
+type DiffAgainstExistingFieldExclusionRule struct {
+	ResourceMatchers []ResourceMatcher
+	Path             ctlres.Path
+}
+
 type OwnershipLabelRule struct {
 	ResourceMatchers []ResourceMatcher
 	Path             ctlres.Path
@@ -290,6 +296,14 @@ func (r DiffAgainstLastAppliedFieldExclusionRule) AsMod() ctlres.FieldRemoveMod
 		Path: r.Path,
 	}
 }
+func (r DiffAgainstExistingFieldExclusionRule) AsMod() ctlres.FieldRemoveMod {
+	return ctlres.FieldRemoveMod{
+		ResourceMatcher: ctlres.AnyMatcher{
+			Matchers: ResourceMatchers(r.ResourceMatchers).AsResourceMatchers(),
+		},
+		Path: r.Path,
+	}
+}
 
 func (r OwnershipLabelRule) AsMod(kvs map[string]string) ctlres.StringMapAppendMod {
 	return ctlres.StringMapAppendMod{
